@@ -102,7 +102,7 @@ def _plot_image(
         Bounding box that the data will fill: (minx, miny, maxx, maxy).
     cbar : Boolean (default = True)
         Turn off colorbar if needed.
-    scale : Boolean (Default = True)
+    scale : Boolean (Default = False)
         Turn off bytescale scaling if needed.
     vmin : Int (Optional)
         Specify the vmin to scale imshow() plots.
@@ -180,7 +180,7 @@ def plot_bands(
         Bounding box that the data will fill: (minx, miny, maxx, maxy).
     cbar : Boolean (default = True)
         Turn off colorbar if needed.
-    scale : Boolean (Default = True)
+    scale : Boolean (Default = False)
         Turn off bytescale scaling if needed.
     vmin : Int (Optional)
         Specify the vmin to scale imshow() plots.
@@ -213,7 +213,7 @@ def plot_bands(
         ...     ep.plot_bands(src.read(),
         ...                   title=titles,
         ...                   figsize=(8, 3))
-        array([<matplotlib.axes._subplots.AxesSubplot object at 0x...
+        array([<AxesSubplot:title={'center':'Red'}>...
     """
     show = False
     try:
@@ -331,7 +331,7 @@ def _stretch_im(arr, str_clip):
     s_max = 100 - str_clip
     arr_rescaled = np.zeros_like(arr)
     for ii, band in enumerate(arr):
-        lower, upper = np.percentile(band, (s_min, s_max))
+        lower, upper = np.nanpercentile(band, (s_min, s_max))
         arr_rescaled[ii] = exposure.rescale_intensity(
             band, in_range=(lower, upper)
         )
@@ -389,7 +389,7 @@ def plot_rgb(
         ...     img_array = src.read()
         >>> # Ensure the input array doesn't have nodata values like -9999
         >>> ep.plot_rgb(img_array)
-        <matplotlib.axes._subplots.AxesSubplot object at 0x...
+        <AxesSubplot:>
 
     """
 
@@ -405,6 +405,11 @@ def plot_rgb(
     if stretch:
         rgb_bands = _stretch_im(rgb_bands, str_clip)
 
+    nan_check = np.isnan(rgb_bands)
+
+    if np.any(nan_check):
+        rgb_bands = np.ma.masked_array(rgb_bands, nan_check)
+
     # If type is masked array - add alpha channel for plotting
     if ma.is_masked(rgb_bands):
         # Build alpha channel
@@ -582,7 +587,11 @@ def hist(
             hist_range = (np.nanmin(arr_comp), np.nanmax(arr_comp))
         fig, ax = plt.subplots(figsize=figsize)
         ax.hist(
-            arr_comp, range=hist_range, bins=bins, color=colors[0], alpha=alpha
+            arr_comp,
+            range=hist_range,
+            bins=bins,
+            color=colors[0],
+            alpha=alpha,
         )
         if title:
             ax.set(title=title[0])
